@@ -1,6 +1,6 @@
 var group__pw__keys =
 [
-    [ "keys.h", "src_2pipewire_2keys_8h.html", null ],
+    [ "src/pipewire/keys.h", "src_2pipewire_2keys_8h.html", null ],
     [ "PW_KEY_PROTOCOL", "group__pw__keys.html#ga75a6c78ce2de6d3dc5ed23abecdbc3bd", null ],
     [ "PW_KEY_ACCESS", "group__pw__keys.html#gad1bfca30c613b28723527132429bb342", null ],
     [ "PW_KEY_CLIENT_ACCESS", "group__pw__keys.html#ga550a0954601e7bf139955115f4b1c030", null ],
@@ -81,6 +81,7 @@ var group__pw__keys =
     [ "PW_KEY_NODE_NETWORK", "group__pw__keys.html#ga7cc45df5bd241b9bb924802082490449", null ],
     [ "PW_KEY_NODE_TRIGGER", "group__pw__keys.html#ga0346a35752b5d7641d7cd7b146733abf", null ],
     [ "PW_KEY_NODE_CHANNELNAMES", "group__pw__keys.html#ga6e00a9edf0a824959dd276c74091e48f", null ],
+    [ "PW_KEY_NODE_DEVICE_PORT_NAME_PREFIX", "group__pw__keys.html#ga5545c435aac2f053d2b4d5f59510818d", null ],
     [ "PW_KEY_PORT_ID", "group__pw__keys.html#ga94975808271e28be225a6fd6d7957762", null ],
     [ "PW_KEY_PORT_NAME", "group__pw__keys.html#ga086fc9bb9864325037b0bd2310816034", null ],
     [ "PW_KEY_PORT_DIRECTION", "group__pw__keys.html#ga4a25213dfcf1d7b7ded06ed9284f1a5f", null ],
@@ -91,6 +92,7 @@ var group__pw__keys =
     [ "PW_KEY_PORT_MONITOR", "group__pw__keys.html#ga52f311c1f1005fda30a47a3b5fc19a77", null ],
     [ "PW_KEY_PORT_CACHE_PARAMS", "group__pw__keys.html#ga2e7814e10b6e027a7808d17ac49f2922", null ],
     [ "PW_KEY_PORT_EXTRA", "group__pw__keys.html#gab4a0aa1d5cff227f1fb19253c0ad221a", null ],
+    [ "PW_KEY_PORT_PASSIVE", "group__pw__keys.html#ga39eb321f72944abae192f6ef8bd8929d", null ],
     [ "PW_KEY_LINK_ID", "group__pw__keys.html#ga2adca834d1bf86f9bb4c3d52af9460e8", null ],
     [ "PW_KEY_LINK_INPUT_NODE", "group__pw__keys.html#ga8bcf374cc8d1cf2c23060479d484c4c8", null ],
     [ "PW_KEY_LINK_INPUT_PORT", "group__pw__keys.html#gae327718323a22392d489db85ad83ab8f", null ],
@@ -162,5 +164,7 @@ var group__pw__keys =
     [ "PW_KEY_VIDEO_RATE", "group__pw__keys.html#gac353c9d9c3ed50ea98806f63f09f9456", null ],
     [ "PW_KEY_VIDEO_FORMAT", "group__pw__keys.html#ga38e8da2c19e9cd1acf5823865f6e9742", null ],
     [ "PW_KEY_VIDEO_SIZE", "group__pw__keys.html#gacc4d098e86d0be0bfe469604c07f4009", null ],
-    [ "PW_KEY_TARGET_OBJECT", "group__pw__keys.html#ga7983296afaca4d7edac60714fa92565b", null ]
+    [ "PW_KEY_TARGET_OBJECT", "group__pw__keys.html#ga7983296afaca4d7edac60714fa92565b", null ],
+    [ "PW_KEY_PRIORITY_MASTER", "group__pw__keys.html#ga1872a5fd956b36a36793554d22d99c6c", null ],
+    [ "PW_KEY_NODE_TARGET", "group__pw__keys.html#ga33441b02b8e14e14451272c2b497a5c9", null ]
 ];
\ No newline at end of file
