@@ -30,7 +30,10 @@ var group__spa__node =
       [ "delay", "structspa__io__clock.html#af8fa38eef9a514c13306bd01da06e776", null ],
       [ "rate_diff", "structspa__io__clock.html#aaddd01ce3e78da42c39efdeab2180035", null ],
       [ "next_nsec", "structspa__io__clock.html#a3242b88552347adc2e406b75f8136060", null ],
-      [ "padding", "structspa__io__clock.html#af53218491c71ee19db11966bb16269ce", null ]
+      [ "target_rate", "structspa__io__clock.html#a02274245ac560717fc5c06ddc66553ff", null ],
+      [ "target_duration", "structspa__io__clock.html#ad5f6c0254efd87a20ca5807b577d3473", null ],
+      [ "target_seq", "structspa__io__clock.html#af91526e984d8c9453e8b98c12dd1f500", null ],
+      [ "padding", "structspa__io__clock.html#ade3b0ef4306272d9a83a361ac3312cad", null ]
     ] ],
     [ "spa_io_video_size", "structspa__io__video__size.html", [
       [ "flags", "structspa__io__video__size.html#ab8f1361af870dd5de789b63b687a22ce", null ],
