@@ -1,5 +1,15 @@
 var NAVTREEINDEX20 =
 {
+"structspa__debug__log__ctx.html#a283294f711d9752bb65c8c09e5a06724":[10,8,3,10,6],
+"structspa__debug__log__ctx.html#a49ae612d5a9f8abff00d338e0f42f338":[10,8,3,10,5],
+"structspa__debug__log__ctx.html#a7834e2a074032895d9760015da193685":[10,8,3,10,1],
+"structspa__debug__log__ctx.html#a7ef044cf8f043c056c0f09e7dc52772f":[10,8,3,10,2],
+"structspa__debug__log__ctx.html#a89c265ff2c1860bc78cb3a71e016c44a":[10,8,3,10,0],
+"structspa__debug__log__ctx.html#abcfc47fb7d6acf39603b9a1547edd1e7":[10,8,3,10,4],
+"structspa__debug__log__ctx.html#afcdc7fd8504c905b64485893b6816ee2":[10,8,3,10,3],
+"structspa__device.html":[10,8,4,3],
+"structspa__device.html#a00d8f19734c35525e99ecaab33113d3f":[10,8,4,3,0],
+"structspa__device__events.html":[10,8,4,7],
 "structspa__device__events.html#a0b9ba211d7f484c7df9ac269d5b49af3":[10,8,4,7,2],
 "structspa__device__events.html#a5b83e45fd5922657978cc36df24cc1c7":[10,8,4,7,3],
 "structspa__device__events.html#a64cea4459b8c4a483d0a2dd684f3e132":[10,8,4,7,1],
@@ -239,15 +249,5 @@ var NAVTREEINDEX20 =
 "structspa__loop__methods.html#a3cc011aae850f2eda426b98655c4a43c":[10,8,9,4,5,1],
 "structspa__loop__methods.html#a72835084d3a698702f9c875ae5aada7a":[10,8,9,4,5,3],
 "structspa__loop__methods.html#a7852de4b031351b586ed1f5375fdc863":[10,8,9,4,5,4],
-"structspa__loop__methods.html#aa1c58c24c44c6161f7c5d81910cc5acc":[10,8,9,4,5,2],
-"structspa__loop__methods.html#ae7dc5184539a2425309dee69d2867dcf":[10,8,9,4,5,0],
-"structspa__loop__utils.html":[10,8,9,4,3],
-"structspa__loop__utils.html#afd3c579e127e4a5d22c1d407e01b2803":[10,8,9,4,3,0],
-"structspa__loop__utils__methods.html":[10,8,9,4,8],
-"structspa__loop__utils__methods.html#a166d2e9aab23ce96b9d7795c3466fc6b":[10,8,9,4,8,2],
-"structspa__loop__utils__methods.html#a4466703d3ee6e18abc89bafea2b0c0ed":[10,8,9,4,8,4],
-"structspa__loop__utils__methods.html#a79ae6123ff0f20029d4e722053b49a11":[10,8,9,4,8,3],
-"structspa__loop__utils__methods.html#aa30b5933fcadb8606772d95471ec7a05":[10,8,9,4,8,6],
-"structspa__loop__utils__methods.html#ab24aa861875574691b833aaaf356a2ad":[10,8,9,4,8,7],
-"structspa__loop__utils__methods.html#abc9a0d7bb777e2c892343b1ca5a6d37d":[10,8,9,4,8,8]
+"structspa__loop__methods.html#aa1c58c24c44c6161f7c5d81910cc5acc":[10,8,9,4,5,2]
 };
