@@ -1,5 +1,15 @@
 var NAVTREEINDEX5 =
 {
+"group__pw__session__manager.html#ga0b0bc42cc601ef5c82090d463694b5c2":[10,7,4,175],
+"group__pw__session__manager.html#ga1069edd0047bbb473360862df48e2919":[10,7,4,123],
+"group__pw__session__manager.html#ga10c31c04d8ed4a8f4670a35af75e8caa":[10,7,4,30],
+"group__pw__session__manager.html#ga13d05f9dfe68e845ef1ffb1fc2cb8565":[10,7,4,99],
+"group__pw__session__manager.html#ga14a1a62d523f118d17acb9bc67bd29eb":[10,7,4,37],
+"group__pw__session__manager.html#ga15ca6aed2bb2a0b703363df5566fe682":[10,7,4,146],
+"group__pw__session__manager.html#ga19f24c2c9fefe01f859c18ec29c2de8e":[10,7,4,164],
+"group__pw__session__manager.html#ga1c21ac4fad8f103846eb54b77422c6b1":[10,7,4,38],
+"group__pw__session__manager.html#ga1df3e3242c1438fe35c454dd3ed41219":[10,7,4,59],
+"group__pw__session__manager.html#ga294e1f89f88e8c143a0fdc10f6b5c19f":[10,7,4,136],
 "group__pw__session__manager.html#ga2de263210f215bfe195aa672b33168d3":[10,7,4,93],
 "group__pw__session__manager.html#ga2e7a34daf8b8253ed9bffd78cdca8e7f":[10,7,4,89],
 "group__pw__session__manager.html#ga2f3475c7169a333132c7adf5ab5f818b":[10,7,4,105],
@@ -149,25 +159,26 @@ var NAVTREEINDEX5 =
 "group__pw__stream.html#ga087a686c66c04e54742cc94c7a5e4e68":[10,0,14],
 "group__pw__stream.html#ga0c274f28a9b9b2fe286719db159f166b":[10,0,23],
 "group__pw__stream.html#ga0e12176f13e654e64e7f5689e7a6dd54":[10,0,19],
-"group__pw__stream.html#ga0ed34dd74ca8f5f46db7c2a4cbd45a94":[10,0,28],
+"group__pw__stream.html#ga0ed34dd74ca8f5f46db7c2a4cbd45a94":[10,0,29],
 "group__pw__stream.html#ga1744b8f160ac0f8d377db9bfdab57053":[10,0,20],
 "group__pw__stream.html#ga19f542ff2b8a51336ae78cfaec8ed896":[10,0,22],
-"group__pw__stream.html#ga2d5e07833039ac7a202caaf297556f52":[10,0,25],
-"group__pw__stream.html#ga3ddd332c45aa95250d3d1d26cf01452a":[10,0,32],
-"group__pw__stream.html#ga5ef987fd1903baa7eba9b10a8cbf5e97":[10,0,31],
+"group__pw__stream.html#ga2d5e07833039ac7a202caaf297556f52":[10,0,26],
+"group__pw__stream.html#ga3ddd332c45aa95250d3d1d26cf01452a":[10,0,33],
+"group__pw__stream.html#ga5ef987fd1903baa7eba9b10a8cbf5e97":[10,0,32],
 "group__pw__stream.html#ga712ca485dc634252d144556074980f0a":[10,0,10],
-"group__pw__stream.html#ga721dc4d5ec4c406ecb0469bfefea468f":[10,0,27],
-"group__pw__stream.html#ga8a3e7ddb0e61c4266ce735a085adb5e7":[10,0,24],
+"group__pw__stream.html#ga721dc4d5ec4c406ecb0469bfefea468f":[10,0,28],
+"group__pw__stream.html#ga8a3e7ddb0e61c4266ce735a085adb5e7":[10,0,25],
 "group__pw__stream.html#ga8b023e0bc564e4e8f70cec17e7c608f4":[10,0,9],
+"group__pw__stream.html#ga97c613bc4ea822bfbbce0de6ab1b9042":[10,0,24],
 "group__pw__stream.html#ga9ceaca6fc9acd9a1af080258d763fb82":[10,0,7],
 "group__pw__stream.html#gaa727d7a41acb9d0ec574f93f01328d30":[10,0,21],
-"group__pw__stream.html#gaafa1055c167dd99ba94bb49ec30603ba":[10,0,30],
-"group__pw__stream.html#gab93fa91d8ea80e562bb5e8f6b5bafe21":[10,0,33],
-"group__pw__stream.html#gabe1c593f34080ea9c8c6231abe4e7386":[10,0,29],
+"group__pw__stream.html#gaafa1055c167dd99ba94bb49ec30603ba":[10,0,31],
+"group__pw__stream.html#gab93fa91d8ea80e562bb5e8f6b5bafe21":[10,0,34],
+"group__pw__stream.html#gabe1c593f34080ea9c8c6231abe4e7386":[10,0,30],
 "group__pw__stream.html#gaca974f99f4545ce623a94c2f06a48dd0":[10,0,15],
 "group__pw__stream.html#gacdd761aac33011a41d1f05cfe9effb11":[10,0,11],
 "group__pw__stream.html#gad9606e2efb479a55ee798f61b82aa49b":[10,0,17],
-"group__pw__stream.html#gadde95a60798bfffa6575306bc07ee7f4":[10,0,26],
+"group__pw__stream.html#gadde95a60798bfffa6575306bc07ee7f4":[10,0,27],
 "group__pw__stream.html#gadfa74620109228a9cfce24b628aa130f":[10,0,13],
 "group__pw__stream.html#gaf21c1b002f78067d2eca97c455970822":[10,0,6],
 "group__pw__stream.html#gaf48f79b09798488557cd6c2f896e0891":[10,0,12],
@@ -238,16 +249,5 @@ var NAVTREEINDEX5 =
 "group__pw__utils.html#gae06596c091a3ae4ddd2b262deec5bd34":[10,6,8,2],
 "group__pw__work__queue.html":[10,5,16],
 "group__pw__work__queue.html#ga31cc6b38eda61a244c7d3fd9024a74db":[10,5,16,5],
-"group__pw__work__queue.html#ga528c2be5bb8ef21bdbe8bfa44485f8bb":[10,5,16,2],
-"group__pw__work__queue.html#ga56673e78071d8a9eb28805331c8b2245":[10,5,16,6],
-"group__pw__work__queue.html#ga7a8bde683bc6cb8091a7d7be9df250fc":[10,5,16,7],
-"group__pw__work__queue.html#gaa9e1df12736d075ba973a19f4333c2eb":[10,5,16,4],
-"group__pw__work__queue.html#gacf03a683177510e35a3859ac16a08119":[10,5,16,3],
-"group__pwtest.html":[10,2],
-"group__pwtest.html#ga0a5763242fdbf0a7a007ca67ee40e8d0":[10,2,9],
-"group__pwtest.html#ga0bc59dec6ed4bae2c6c03aea2c8789ae":[10,2,49],
-"group__pwtest.html#ga10ad32a379491ecbbb15bb8bc1f7f803":[10,2,7],
-"group__pwtest.html#ga1108ba45f915c9df17cc28357a21f5bf":[10,2,47],
-"group__pwtest.html#ga135297caa69f5e14b2b20148850d080b":[10,2,44],
-"group__pwtest.html#ga1536e136ab274b09533862681ddf8075":[10,2,29]
+"group__pw__work__queue.html#ga528c2be5bb8ef21bdbe8bfa44485f8bb":[10,5,16,2]
 };
