@@ -1,5 +1,16 @@
 var NAVTREEINDEX7 =
 {
+"group__spa__cpu.html#gaabed68d3b3d4db276c57891df69fbc93":[10,8,9,0,49],
+"group__spa__cpu.html#gab0e2f34eb8b3aa5f1eb74be67decae9a":[10,8,9,0,6],
+"group__spa__cpu.html#gabb4142740151dfe408cb49f344da06de":[10,8,9,0,43],
+"group__spa__cpu.html#gabed152078bde7fcafccb72345c40d71c":[10,8,9,0,61],
+"group__spa__cpu.html#gac0071a662de46285708b0c8c32e4be2e":[10,8,9,0,29],
+"group__spa__cpu.html#gac3575bc4548e5cb7c87a9e59dce85e91":[10,8,9,0,13],
+"group__spa__cpu.html#gac8a0291e09ea6fdcd49b2a8c3988b223":[10,8,9,0,41],
+"group__spa__cpu.html#gacd9379b41a5fc4ca989f106515ab72e4":[10,8,9,0,54],
+"group__spa__cpu.html#gad24522ec05d1ded3a3d9b2a3274b0030":[10,8,9,0,30],
+"group__spa__cpu.html#gad4c6b81675ec1a16c23239041970f099":[10,8,9,0,12],
+"group__spa__cpu.html#gadbf1c05dc94b098500b335c980a20f73":[10,8,9,0,27],
 "group__spa__cpu.html#gade1463bb6f0e53ab480be27ac0b4383c":[10,8,9,0,17],
 "group__spa__cpu.html#gae10fa710c9aa3527eaf37d8a3bfd72d2":[10,8,9,0,26],
 "group__spa__cpu.html#gae496a2c1b18ae116ae1c2a7b7f0e66c3":[10,8,9,0,37],
@@ -238,16 +249,5 @@ var NAVTREEINDEX7 =
 "group__spa__json.html#ga16c676cb24334b96a9e1eaf0d73ec39f":[10,8,8,6,17],
 "group__spa__json.html#ga255f1962c8cb52c861c197533693732c":[10,8,8,6,16],
 "group__spa__json.html#ga2b070aa36336cbe95ffe1871672ecd70":[10,8,8,6,23],
-"group__spa__json.html#ga2fe3d2f299b7227b36c93c84c0117f96":[10,8,8,6,30],
-"group__spa__json.html#ga4dbbb0d8d43216c23d20b08be1650437":[10,8,8,6,8],
-"group__spa__json.html#ga54e9a5e2c169224c8ae8953135290505":[10,8,8,6,6],
-"group__spa__json.html#ga588b735c81b1826b44076463ff7bff07":[10,8,8,6,29],
-"group__spa__json.html#ga5e367b9297cbf21d391f4d1b2ffe4734":[10,8,8,6,24],
-"group__spa__json.html#ga604d3512668501ff1a1d5897c0208416":[10,8,8,6,22],
-"group__spa__json.html#ga62fe1f66450b557cf2c5b5e65a5fcd70":[10,8,8,6,26],
-"group__spa__json.html#ga6502b3572751902a364273b0cdaa13c4":[10,8,8,6,12],
-"group__spa__json.html#ga6864ecec42015a48aa8991d6a2c8d6fa":[10,8,8,6,32],
-"group__spa__json.html#ga6c02b51e71c406e5b7f014858bdf579b":[10,8,8,6,25],
-"group__spa__json.html#ga6d871debd28993273c3cbb1b0f7fce64":[10,8,8,6,2],
-"group__spa__json.html#ga7c080249c08879b0576e5225a67fde7e":[10,8,8,6,19]
+"group__spa__json.html#ga2fe3d2f299b7227b36c93c84c0117f96":[10,8,8,6,30]
 };
